==> okta-sdk-api-21.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/PasswordPolicyRecoveryFactors.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.PasswordPolicyRecoveryEmail;
import com.okta.sdk.resource.model.PasswordPolicyRecoveryFactorSettings;
import com.okta.sdk.resource.model.PasswordPolicyRecoveryQuestion;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Settings for the Factors that can be used for recovery
 */
@ApiModel(description = "Settings for the Factors that can be used for recovery")
@JsonPropertyOrder({ PasswordPolicyRecoveryFactors.JSON_PROPERTY_OKTA_CALL,
        PasswordPolicyRecoveryFactors.JSON_PROPERTY_OKTA_EMAIL, PasswordPolicyRecoveryFactors.JSON_PROPERTY_OKTA_SMS,
        PasswordPolicyRecoveryFactors.JSON_PROPERTY_RECOVERY_QUESTION })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class PasswordPolicyRecoveryFactors implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_OKTA_CALL = "okta_call";
    private PasswordPolicyRecoveryFactorSettings oktaCall;

    public static final String JSON_PROPERTY_OKTA_EMAIL = "okta_email";
    private PasswordPolicyRecoveryEmail oktaEmail;

    public static final String JSON_PROPERTY_OKTA_SMS = "okta_sms";
    private PasswordPolicyRecoveryFactorSettings oktaSms;

    public static final String JSON_PROPERTY_RECOVERY_QUESTION = "recovery_question";
    private PasswordPolicyRecoveryQuestion recoveryQuestion;

    public PasswordPolicyRecoveryFactors() {
    }

    public PasswordPolicyRecoveryFactors oktaCall(PasswordPolicyRecoveryFactorSettings oktaCall) {

        this.oktaCall = oktaCall;
        return this;
    }

    /**
     * Get oktaCall
     *
     * @return oktaCall
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_OKTA_CALL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PasswordPolicyRecoveryFactorSettings getOktaCall() {
        return oktaCall;
    }

    @JsonProperty(JSON_PROPERTY_OKTA_CALL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setOktaCall(PasswordPolicyRecoveryFactorSettings oktaCall) {
        this.oktaCall = oktaCall;
    }

    public PasswordPolicyRecoveryFactors oktaEmail(PasswordPolicyRecoveryEmail oktaEmail) {

        this.oktaEmail = oktaEmail;
        return this;
    }

    /**
     * Get oktaEmail
     *
     * @return oktaEmail
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_OKTA_EMAIL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PasswordPolicyRecoveryEmail getOktaEmail() {
        return oktaEmail;
    }

    @JsonProperty(JSON_PROPERTY_OKTA_EMAIL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setOktaEmail(PasswordPolicyRecoveryEmail oktaEmail) {
        this.oktaEmail = oktaEmail;
    }

    public PasswordPolicyRecoveryFactors oktaSms(PasswordPolicyRecoveryFactorSettings oktaSms) {

        this.oktaSms = oktaSms;
        return this;
    }

    /**
     * Get oktaSms
     *
     * @return oktaSms
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_OKTA_SMS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PasswordPolicyRecoveryFactorSettings getOktaSms() {
        return oktaSms;
    }

    @JsonProperty(JSON_PROPERTY_OKTA_SMS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setOktaSms(PasswordPolicyRecoveryFactorSettings oktaSms) {
        this.oktaSms = oktaSms;
    }

    public PasswordPolicyRecoveryFactors recoveryQuestion(PasswordPolicyRecoveryQuestion recoveryQuestion) {

        this.recoveryQuestion = recoveryQuestion;
        return this;
    }

    /**
     * Get recoveryQuestion
     *
     * @return recoveryQuestion
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_RECOVERY_QUESTION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PasswordPolicyRecoveryQuestion getRecoveryQuestion() {
        return recoveryQuestion;
    }

    @JsonProperty(JSON_PROPERTY_RECOVERY_QUESTION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setRecoveryQuestion(PasswordPolicyRecoveryQuestion recoveryQuestion) {
        this.recoveryQuestion = recoveryQuestion;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PasswordPolicyRecoveryFactors passwordPolicyRecoveryFactors = (PasswordPolicyRecoveryFactors) o;
        return Objects.equals(this.oktaCall, passwordPolicyRecoveryFactors.oktaCall)
                && Objects.equals(this.oktaEmail, passwordPolicyRecoveryFactors.oktaEmail)
                && Objects.equals(this.oktaSms, passwordPolicyRecoveryFactors.oktaSms)
                && Objects.equals(this.recoveryQuestion, passwordPolicyRecoveryFactors.recoveryQuestion);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(oktaCall, oktaEmail, oktaSms, recoveryQuestion);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PasswordPolicyRecoveryFactors {\n");
        sb.append("    oktaCall: ").append(toIndentedString(oktaCall)).append("\n");
        sb.append("    oktaEmail: ").append(toIndentedString(oktaEmail)).append("\n");
        sb.append("    oktaSms: ").append(toIndentedString(oktaSms)).append("\n");
        sb.append("    recoveryQuestion: ").append(toIndentedString(recoveryQuestion)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/PasswordPolicyRecoveryFactors.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.PasswordPolicyRecoveryEmail;
import com.okta.sdk.resource.model.PasswordPolicyRecoveryFactorSettings;
import com.okta.sdk.resource.model.PasswordPolicyRecoveryQuestion;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Settings for the Factors that can be used for recovery
 */
@ApiModel(description = "Settings for the Factors that can be used for recovery")
@JsonPropertyOrder({ PasswordPolicyRecoveryFactors.JSON_PROPERTY_OKTA_CALL,
        PasswordPolicyRecoveryFactors.JSON_PROPERTY_OKTA_EMAIL, PasswordPolicyRecoveryFactors.JSON_PROPERTY_OKTA_SMS,
        PasswordPolicyRecoveryFactors.JSON_PROPERTY_RECOVERY_QUESTION })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class PasswordPolicyRecoveryFactors implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_OKTA_CALL = "okta_call";
    private PasswordPolicyRecoveryFactorSettings oktaCall;

    public static final String JSON_PROPERTY_OKTA_EMAIL = "okta_email";
    private PasswordPolicyRecoveryEmail oktaEmail;

    public static final String JSON_PROPERTY_OKTA_SMS = "okta_sms";
    private PasswordPolicyRecoveryFactorSettings oktaSms;

    public static final String JSON_PROPERTY_RECOVERY_QUESTION = "recovery_question";
    private PasswordPolicyRecoveryQuestion recoveryQuestion;

    public PasswordPolicyRecoveryFactors() {
    }

    public PasswordPolicyRecoveryFactors oktaCall(PasswordPolicyRecoveryFactorSettings oktaCall) {

        this.oktaCall = oktaCall;
        return this;
    }

    /**
     * Get oktaCall
     *
     * @return oktaCall
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_OKTA_CALL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PasswordPolicyRecoveryFactorSettings getOktaCall() {
        return oktaCall;
    }

    @JsonProperty(JSON_PROPERTY_OKTA_CALL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setOktaCall(PasswordPolicyRecoveryFactorSettings oktaCall) {
        this.oktaCall = oktaCall;
    }

    public PasswordPolicyRecoveryFactors oktaEmail(PasswordPolicyRecoveryEmail oktaEmail) {

        this.oktaEmail = oktaEmail;
        return this;
    }

    /**
     * Get oktaEmail
     *
     * @return oktaEmail
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_OKTA_EMAIL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PasswordPolicyRecoveryEmail getOktaEmail() {
        return oktaEmail;
    }

    @JsonProperty(JSON_PROPERTY_OKTA_EMAIL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setOktaEmail(PasswordPolicyRecoveryEmail oktaEmail) {
        this.oktaEmail = oktaEmail;
    }

    public PasswordPolicyRecoveryFactors oktaSms(PasswordPolicyRecoveryFactorSettings oktaSms) {

        this.oktaSms = oktaSms;
        return this;
    }

    /**
     * Get oktaSms
     *
     * @return oktaSms
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_OKTA_SMS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PasswordPolicyRecoveryFactorSettings getOktaSms() {
        return oktaSms;
    }

    @JsonProperty(JSON_PROPERTY_OKTA_SMS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setOktaSms(PasswordPolicyRecoveryFactorSettings oktaSms) {
        this.oktaSms = oktaSms;
    }

    public PasswordPolicyRecoveryFactors recoveryQuestion(PasswordPolicyRecoveryQuestion recoveryQuestion) {

        this.recoveryQuestion = recoveryQuestion;
        return this;
    }

    /**
     * Get recoveryQuestion
     *
     * @return recoveryQuestion
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_RECOVERY_QUESTION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PasswordPolicyRecoveryQuestion getRecoveryQuestion() {
        return recoveryQuestion;
    }

    @JsonProperty(JSON_PROPERTY_RECOVERY_QUESTION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setRecoveryQuestion(PasswordPolicyRecoveryQuestion recoveryQuestion) {
        this.recoveryQuestion = recoveryQuestion;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PasswordPolicyRecoveryFactors passwordPolicyRecoveryFactors = (PasswordPolicyRecoveryFactors) o;
        return Objects.equals(this.oktaCall, passwordPolicyRecoveryFactors.oktaCall)
                && Objects.equals(this.oktaEmail, passwordPolicyRecoveryFactors.oktaEmail)
                && Objects.equals(this.oktaSms, passwordPolicyRecoveryFactors.oktaSms)
                && Objects.equals(this.recoveryQuestion, passwordPolicyRecoveryFactors.recoveryQuestion);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(oktaCall, oktaEmail, oktaSms, recoveryQuestion);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PasswordPolicyRecoveryFactors {\n");
        sb.append("    oktaCall: ").append(toIndentedString(oktaCall)).append("\n");
        sb.append("    oktaEmail: ").append(toIndentedString(oktaEmail)).append("\n");
        sb.append("    oktaSms: ").append(toIndentedString(oktaSms)).append("\n");
        sb.append("    recoveryQuestion: ").append(toIndentedString(recoveryQuestion)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
